@@ -16,8 +16,8 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -28,14 +28,18 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include "rpl_stdint.h"
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20050525
+#if !defined(_LIBHX_H) || _LIBHX_H < 20050626
 #    error ----------------------------------------
 #    error You need a newer version of libHX
-#    error (at least 1.5.0 / 0_5-20050525)
+#    error (at least 1.5.3 / 0_5-20050626)
 #    error http:/jengelh.hopto.org/coding/libHX.php
 #    error ----------------------------------------
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define RECEIVE_FULL(fd, ptr, sz) \
     (recv((fd), (ptr), (sz), MSG_WAITALL) == (sz))
 
@@ -89,6 +93,10 @@ extern void log_close(struct tty *);
 extern void notify(int, const char *, ...);
 extern ssize_t send_wait(int, const void *, size_t, int);
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
+
 #endif // TTYRPLD_RDSH_H
 
 //=============================================================================
