@@ -103,7 +103,7 @@ static inline unsigned int min_uint(unsigned int, unsigned int);
 static inline uint32_t mkdev_26(unsigned long, unsigned long);
 static int mv_buffer(struct rpldev_packet *, const void *, size_t);
 static inline void mv_buffer2(const void *, size_t);
-static inline void mv_to_user(char __user *, size_t);
+static inline int mv_to_user(char __user *, size_t);
 
 // Variables
 static DECLARE_WAIT_QUEUE_HEAD(Pull_queue);
@@ -357,6 +357,8 @@ static int urpl_open(struct inode *inode, struct file *filp) {
 static ssize_t urpl_read(struct file *filp, char __user *buf, size_t count,
  loff_t *ppos)
 {
+    int eax;
+
     // Nothing read, nothing done
     if(count == 0) { return 0; }
 
@@ -373,11 +375,11 @@ static ssize_t urpl_read(struct file *filp, char __user *buf, size_t count,
 
     // Data is available, so give it to the user
     count = min_uint(count, avail_R());
-    mv_to_user(buf, count);
+    eax   = mv_to_user(buf, count);
 
     up(&Buffer_lock);
     filp->f_dentry->d_inode->i_atime = CURRENT_TIME;
-    return count;
+    return (eax != 0) ? eax : count;
 }
 
 static loff_t urpl_seek(struct file *filp, loff_t offset, int origin) {
@@ -485,7 +487,7 @@ static inline void fill_time(struct timeval *tv) {
 }
 
 static inline unsigned int min_uint(unsigned int a, unsigned int b) {
-    return a < b ? a : b;
+    return (a < b) ? a : b;
 }
 
 static inline uint32_t mkdev_26(unsigned long maj, unsigned long min) {
@@ -532,23 +534,27 @@ static inline void mv_buffer2(const void *src, size_t count) {
     return;
 }
 
-static inline void mv_to_user(char __user *dest, size_t count) {
+static inline int mv_to_user(char __user *dest, size_t count) {
     /* mv_to_user() reads COUNT bytes from the circulary buffer and puts it
     into userspace memory. The caller must make sure that COUNT is at most
     avail_R(). */
     size_t x = Buffer + Bufsize - BufRP;
+    int eax = 0;
 
     /* Since this operation might block due to userspace page faults, the
     userspace daemon should really have DEST memory-locked. */
     if(count < x) {
-        copy_to_user(dest, BufRP, count);
-        BufRP += count;
+        if((eax = copy_to_user(dest, BufRP, count)) == 0) {
+            BufRP += count;
+        }
     } else {
-        copy_to_user(dest, BufRP, x);
-        copy_to_user(dest + x, Buffer, count - x);
-        BufRP = Buffer + count - x;
+        if((eax = copy_to_user(dest, BufRP, x)) == 0 &&
+         (eax = copy_to_user(dest + x, Buffer, count - x)) == 0) {
+            BufRP = Buffer + count - x;
+        }
     }
-    return;
+
+    return eax;
 }
 
 //=============================================================================
