@@ -71,7 +71,7 @@ struct {
 // Functions
 static int replay_file(int, const char *);
 static void e_proc(int, struct rpldsk_packet *, struct pctrl_info *, char *,
-  struct timeval *, unsigned long *);
+  struct timeval *, long *);
 
 static unsigned long calc_ovcorr(unsigned long, int);
 static int find_next_packet(int);
@@ -236,7 +236,7 @@ static int replay_file(int fd, const char *name) {
 }
 
 static void e_proc(int fd, struct rpldsk_packet *p, struct pctrl_info *i,
-  char *tick, struct timeval *stamp, unsigned long *skew)
+  char *tick, struct timeval *stamp, long *skew)
 {
     if(i->sktype == PCTRL_SKPACK && i->skval-- > 0) {
         // Just skip, do not update tick/stamp/skew/delta
